# Coflux → Clients → Python

Coflux is an open-source workflow engine. Use it to orchestrate and observe computational workflows, defined in plain Python. Suitable for data pipelines, background tasks, chat bots.

This is the Python client, which is used for defining workflows. It also includes the CLI, which can be used for running agents, configuring new projects, and starting runs.

Refer to the [docs](https://docs.coflux.com) for more details.
